##  Creating S-User IDs
### Context
In the user management area of SAP for Me, administrators can request S-user IDs for their colleagues and assign them the required authorizations. For example, you might request S-user IDs for all workspace admins to make sure they can submit support tickets.
Learn more about authorizations in [About the User, Authorization and Administrator Concept![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fsupport.sap.com%2Fcontent%2Fs4m%2Fhelp%2Faccess%2Fuser-admin-concept.html?locale=en-US&state=PRODUCTION&version=CLOUD "https://support.sap.com/content/s4m/help/access/user-admin-concept.html").
### Procedure
  1. Go to SAP for Me.
  2. In the User Management area, go to Home > Users & Contacts > User Management.
  3. Choose Request User.
  4. Enter the user’s details in the Request User  form.
  5. Optional: If you’ve set up authorization packages for user groups within your organization, you can also assign them at this time. Choose "+" to select an authorization package.
Learn more about authorization packages in Creating Authorization Packages.
  6. Choose Submit.
  7. On the User was requested confirmation screen, choose OK.


### Results
The new user receives an email from SAP Notification Services with the new S-user ID and an activation link. The activation link is valid for 10 days.
